;----------------------------------------------------------------------------------------------------
;             Agricultural supply chain agent-based simulation, a case study in Colombia
;                                 Built by: Cesar Garcia-Diaz
;                     This version: December 30, 2016, 19:55 Hrs. (UTC/GMT - 5)
;                   Additional experiments: Aoril 28, 2017, 18:05 Hrs. (UTC/GMT - 5)
;----------------------------------------------------------------------------------------------------

extensions [table csv]

;---------------------------------------------------------
;    VARIABLE / AGENT DEFINITIONS & DECLARATIONS
;---------------------------------------------------------

;--------------------------------------------------------
breed [producers producer]           ;creates producers
breed [intermediaries intermediary]  ;creates intermediaries
breed [wholesalers wholesaler]       ;creates wholesale markets
breed [farm-markets farm-market]     ;creates farm markets

producers-own [current-market           ;indicates the market the producer is selling to (intermediary or downstream market)
               last-profit              ;profit last (i.e., most recent) iteration
               profits                  ;shows cumulative profits
               q-value-list             ;tracks the assessment values of intermediaries + downstream market
               unit-var-cost            ;unit production cost ($USD/Ton, 1 $USD = 3000 COP)
               producer-quantity        ;producer quantity (Ton / month)
               unit-transport-cost      ;unit transport cost ($USD/Km)
               producer-location        ;there are 459 possible locations
               inter-location-list      ;contains locations of potential intermediaries
               distance-to-intermediary ;distance (mts.) to each intermediary location
               producer-clients         ;list that contains the id's of all served intemediaries and chosen farm market
              ]

intermediaries-own [buying-cost     ;price at which intermediary buys from producers; reference: price to end consumer: Y($USD/Ton) = 336.51 - 0.0014*X(Ton.)
                    buying-q        ;amount adquired from producers
                    profits         ;cumulative profits
                    last-profit     ;profit last iteration
                    inter-location  ;intermediary location. There are 94 possible locations
                    distance-value  ;records the distance to wholesaler (Bogota), in Km.
                    my-producers    ;producer id's from which quantity has been bought
                   ]

wholesalers-own[market-buying-price  ;market price; reference: price to end consumer: Y($USD/Ton) = 336.51 - 0.0014*X(Ton.)
                total-quantity       ;market quantity Q
                market-sale-price    ;price at which consumers buy
                profits              ;cumulative profits
                last-profit          ;profit last iteration
                my-intermediaries    ;intermediaries id's from which quantity has been bought
               ]

farm-markets-own[market-buying-price  ;market price; reference: price to end consumer: Y($USD/Ton) = 336.51 - 0.0014*X(Ton.)
                 total-quantity       ;market quantity Q
                 market-sale-price    ;price at which consumers buy
                 profits              ;cumulative profits
                 last-profit          ;profit last iteration
                 my-producers         ;producer id's from which quantity has been bought
                ]

globals [time-horizon               ;simulation horizon
         q-producer-starting-value  ;reinforcement learning algorithm
         unit-cost-vector1           ;vector that contains unit production cost values for each producer location (459 * 1 = 459 values). All agents are large producers
         unit-cost-vector2           ;vector that contains unit production cost values for each producer location (459 * 2 = 918 values). All agents are mid-sized producers
         unit-cost-vector3           ;vector that contains unit production cost values for each producer location (459 * 3 = 1377 values). All agents are small producers
         production-quantity-vector1 ;vector that contains production volumes per location (459 * 1 = 459 producers). All agents are large producers / 459 values
         production-quantity-vector2 ;vector that contains production volumes per location (459 * 2 = 918 producers). All agents are mid-sized producers / 459 values
         production-quantity-vector3 ;vector that contains production volumes per location (459 * 3 = 1377 producers). All agents are small producers / 459 values
         distance-vector             ;vector that contains distances from intermediaries to main wholesaler location (Bogota, 94 values)
         unit-transport-cost-vector1 ;vector that contains unit transport costs per location (when all producers are large) / 459 values
         unit-transport-cost-vector2 ;vector that contains unit transport costs per location (when all producers are mid-sized) / 459 values
         unit-transport-cost-vector3 ;vector that contains unit transport costs per location (when all producers are small) / 459 values
         prod-inter-distance         ;table that records the distances from producers to intermediaries (according to inter-by-prod)
         inter-by-prod               ;table that records intermediaries' location per producer's location
         memory                      ;number of diferent clients a given producer can serve in the whole simulation
         active-probability          ;represents the probability of being an active producer (every tick)
         factor1                     ;markup that intermediaries / farm markets get over producers
         factor2                     ;markup that wholesalers get over intermediaries
         inter-transport-cost        ;intermediation transport cost ($USD / Km-Ton.)
        ]
;--------------------------------------------------------

;--------------------------------------------------------
;                 SETUP PROCEDURE
;--------------------------------------------------------
to distance-matrix-construction
   ;Builds a table with al feasible distance between all producers' LOCATIONS and intermediaries' LOCATIONS (in mts.).
   ;There might be several producers sharing the same location / severeal intermediaries sharing the same location
   ;Producer locations: 0, 1,..., 458
   ;Intermediary locations: 0, 1,..., 93

   set-current-directory "C:\\Users\\ce.garcia392\\Documents"
   ;set-current-directory "C:\\Users\\Cesar Garcia Diaz\\Dropbox\\ABM Food Supply Chain - GonzaloMejia"
   let row-counter 0
   file-open "distance_matrix.csv"
   set prod-inter-distance table:make
   set inter-by-prod table:make
   while [not file-at-end?] [
          let esta-fila csv:from-row file-read-line
          let column-counter 0
          let positions [0]
          repeat 93 [set positions lput (last positions + 1) positions]

          repeat 94 [
          if (item column-counter esta-fila = 500000) [
                                              set positions replace-item column-counter positions 500000
                                             ]
          set column-counter column-counter + 1
          ]
          set esta-fila remove 500000 esta-fila
          set positions remove 500000 positions
          table:put prod-inter-distance row-counter esta-fila
          table:put inter-by-prod row-counter positions
          set row-counter row-counter + 1
    ]

   file-close
end

to setup
   clear-all
   random-seed (100 * timer)
   distance-matrix-construction

   ;setting default shapes
   set-default-shape producers "circle"
   set-default-shape intermediaries "circle"
   set-default-shape wholesalers "square"
   set-default-shape farm-markets "square"
   set memory 15 ;maximum number of diferent clients any producer can serve in the simulation (number of intermediaries + one farm market)
   set active-probability 1
   set factor1 1.30
   set factor2 1.10
   set inter-transport-cost (325 / 3000) ; $COP 325 / Km-Ton; 1 $USD = 3000 $COP
   ask patches [set pcolor white]
   set time-horizon 200
   set q-producer-starting-value 100

   ;-----------------------------------------
   ;         slider buttons
   ;-----------------------------------------

   ;-----------------------------------------
   ;(i)   number-producers = 459 * number-producers-per-location ;according to data, there are 459 possible locations
   ;(ii)  number-intermediaries = 94 * number-intermediaries-per-location ;according to data, there are 94 possible locations
   ;(iii) number of farm markets, between 1 and 50
   ;(iv)  reduction-factor between 0.1 and 1
   ;-----------------------------------------

   ;unit production cost values calibrated according to real data (in $USD/Ton; 3000 COP = 1 USD). We assume ONE/TWO/THREE producer per town / location - 459 location values
   ;only large producers - One producer per location
   set unit-cost-vector1 [200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  232.67  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  232.67  200.00  232.67  200.00  200.00  232.67  232.67  200.00
                          200.00  232.67  232.67  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  232.67  200.00  232.67  232.67  200.00  232.67  232.67  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  232.67  232.67  200.00  200.00  232.67  232.67  200.00  200.00  232.67  232.67
                          200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  232.67  200.00  200.00  200.00  232.67  200.00  232.67  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00
                          232.67  232.67  232.67  200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  232.67  200.00  200.00  200.00  200.00  200.00  232.67  232.67  200.00
                          200.00  232.67  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
                          200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00  200.00
   ]

   ;Mid-sized producers - Two producers per location
   set unit-cost-vector2 [219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  232.67  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  232.67  219.33  232.67  219.33  219.33  232.67  232.67  219.33
                          219.33  232.67  232.67  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  232.67  219.33  232.67  232.67  219.33  232.67  232.67  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  232.67  232.67  219.33  219.33  232.67  232.67  219.33  219.33  232.67  232.67
                          219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  232.67  219.33  219.33  219.33  232.67  219.33  232.67  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33
                          232.67  232.67  232.67  219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  232.67  219.33  219.33  219.33  219.33  219.33  232.67  232.67  219.33
                          219.33  232.67  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33
                          219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33  219.33

   ]

   ;small producers - Three producers per location
   set unit-cost-vector3 []
   repeat 459 [set unit-cost-vector3 lput 232.67 unit-cost-vector3]


   ;production volumes (Tons/producer-month) per location (459 values) - We assume ONE / TWO / THREE producers per town / location (depending on scenario)
   ;only large producers - One producer per location
   set production-quantity-vector1 [162  39  257  24  6  177  113  288  301  18  55  351  61  72  508  43  503  34  881  61  42  201  68  87  92  203  21  10  2  11  2  3  8  8  43  434
                                    58  2  5  528  37  878  143  113  159  360  2  2  64  14  21  11  113  32  791  18  912  195  80  352  307  362  658  88  531  156  341  587  766  5
                                    13  5  74  3  3  42  8  24  31  5  42  251  421  77  492  6  206  109  21  156  256  2  2  3  2  3  8  2  2  3  5  2  2  2  10  170  225  3  29  399
                                    170  71  2  3  301  26  175  37  183  10  26  206  8  2  5  2  2  5  2  2  2  3  3  330  10  43  56  555  2  8  6  248  10  18  43  270  60  16  10
                                    3  18  2  444  29  119  137  77  183  43  50  27  74  133  227  3  82  3  26  2  56  2  2  5  5  2  2  5  19  2  2  3  6  16  2  436  217  246  55
                                    100  142  267  505  32  37  27  72  405  495  103  39  3  3  13  16  55  55  111  10  803  5  312  191  11  5  10  3  11  2  6  101  6  10  5  90
                                    261  14  3  2  6  2  34  13  156  2  164  2  154  10  29  45  47  5  27  216  8  8  93  26  26  6  8  76  129  5  2  5  380  29  1216  10  95  18  351
                                    179  85  10  16  2  27  97  27  31  19  2  8  21  27  55  16  114  56  127  8  159  69  90  43  220  167  19  42  40  175  13  92  143  23  8  51  116
                                    77  109  58  13  21  2  233  154  159  832  109  164  296  58  71  114  415  18  109  18  135  5  151  84  212  48  31  24  77  79  18  26  172  29
                                    27  13  2  55  51  55  6  372  14  24  11  2  11  240  23  113  296  727  388  156  162  264  153  95  158  521  29  71  5  2  85  51  42  14  21  32
                                    153  521  43  236  47  6  58  354  158  43  13  417  14  8  145  90  116  306  82  2  3  5  97  2  14  5  5  11  66  172  2  2  2  35  2  85  24  610
                                    72  146  162  2  3  6  3  852  3  2  2  8  5  2  3  43  58  19  5  13  3  166  13  10  34  105  159  5  5  3  106  27  66  8  5  34  72  169  88  1208
                                    32  344  513  999  80  61  27  3  79  27  5
   ]

   ;Mid-sized producers (Tons/producer-month) - Two producers per location
   set production-quantity-vector2 [73  17  116  11  3  79  51  129  135  8  25  157  27  32  228  19  226  15  396  27  19  90  30  39  41  91  9  4  1  5  1  1  4  4  19  195  26  1  2
                                    237  17  394  64  51  71  162  1  1  29  6  9  5  51  14  355  8  409  87  36  158  138  162  295  40  238  70  153  264  344  2  6  2  33  1  1  19  4
                                    11  14  2  19  113  189  35  221  3  92  49  9  70  115  1  1  1  1  1  4  1  1  1  2  1  1  1  4  77  101  1  13  179  77  32  1  1  135  12  79  17  82
                                    4  12  92  4  1  2  1  1  2  1  1  1  1  1  148  4  19  25  249  1  4  3  111  4  8  19  121  27  7  4  1  8  1  199  13  53  61  35  82  19  22  12  33
                                    60  102  1  37  1  12  1  25  1  1  2  2  1  1  2  9  1  1  1  3  7  1  196  97  110  25  45  64  120  227  14  17  12  32  182  222  46  17  1  1  6  7
                                    25  25  50  4  360  2  140  86  5  2  4  1  5  1  3  45  3  4  2  40  117  6  1  1  3  1  15  6  70  1  74  1  69  4  13  20  21  2  12  97  4  4  42  12
                                    12  3  4  34  58  2  1  2  170  13  546  4  43  8  157  80  38  4  7  1  12  43  12  14  9  1  4  9  12  25  7  51  25  57  4  71  31  40  19  99  75  9
                                    19  18  79  6  41  64  10  4  23  52  35  49  26  6  9  1  105  69  71  373  49  74  133  26  32  51  186  8  49  8  61  2  68  38  95  22  14  11  35  35
                                    8  12  77  13  12  6  1  25  23  25  3  167  6  11  5  1  5  108  10  51  133  326  174  70  73  118  69  43  71  234  13  32  2  1  38  23  19  6  9  14
                                    69  234  19  106  21  3  26  159  71  19  6  187  6  4  65  40  52  137  37  1  1  2  43  1  6  2  2  5  30  77  1  1  1  16  1  38  11  274  32  66  73
                                    1  1  3  1  383  1  1  1  4  2  1  1  19  26  9  2  6  1  74  6  4  15  47  71  2  2  1  48  12  30  4  2  15  32  76  40  542  14  155  230  448  36  27
                                    12  1  35  12  2
   ]


   ;small producers (Tons/producer-month)- Three producer pers location
   set production-quantity-vector3 [41.05  9.75  65.02  6.10  1.63  44.70  28.45  72.74  75.99  4.47  13.82  88.59  15.44  18.29  128.42  10.97  127.20  8.53  222.70  15.44  10.57  50.80  17.07
                                    21.95  23.16  51.21  5.28  2.44  0.41  2.84  0.41  0.81  2.03  2.03  10.97  109.73  14.63  0.41  1.22  133.30  9.35  221.89  36.17  28.45  40.23  91.03  0.41
                                    0.41  16.26  3.66  5.28  2.84  28.45  8.13  199.94  4.47  230.42  49.17  20.32  89.00  77.62  91.44  166.21  22.35  134.11  39.42  86.15  148.33  193.44  1.22
                                    3.25  1.22  18.69  0.81  0.81  10.57  2.03  6.10  7.72  1.22  10.57  63.40  106.47  19.51  124.36  1.63  52.02  27.63  5.28  39.42  64.62  0.41  0.41  0.81
                                    0.41  0.81  2.03  0.41  0.41  0.81  1.22  0.41  0.41  0.41  2.44  43.08  56.89  0.81  7.32  100.78  43.08  17.88  0.41  0.81  75.99  6.50  44.30  9.35  46.33
                                    2.44  6.50  52.02  2.03  0.41  1.22  0.41  0.41  1.22  0.41  0.41  0.41  0.81  0.81  83.31  2.44  10.97  14.22  140.20  0.41  2.03  1.63  62.58  2.44  4.47
                                    10.97  68.27  15.04  4.06  2.44  0.81  4.47  0.41  112.16  7.32  30.07  34.54  19.51  46.33  10.97  12.60  6.91  18.69  33.73  57.30  0.81  20.73  0.81  6.50
                                    0.41  14.22  0.41  0.41  1.22  1.22  0.41  0.41  1.22  4.88  0.41  0.41  0.81  1.63  4.06  0.41  110.13  54.86  62.18  13.82  25.20  35.76  67.46  127.61  8.13
                                    9.35  6.91  18.29  102.41  125.17  26.01  9.75  0.81  0.81  3.25  4.06  13.82  13.82  28.04  2.44  202.79  1.22  78.84  48.36  2.84  1.22  2.44  0.81  2.84
                                    0.41  1.63  25.60  1.63  2.44  1.22  22.76  65.84  3.66  0.81  0.41  1.63  0.41  8.53  3.25  39.42  0.41  41.45  0.41  39.01  2.44  7.32  11.38  11.79  1.22
                                    6.91  54.46  2.03  2.03  23.57  6.50  6.50  1.63  2.03  19.10  32.51  1.22  0.41  1.22  95.91  7.32  307.23  2.44  23.98  4.47  88.59  45.11  21.54  2.44  4.06
                                    0.41  6.91  24.38  6.91  7.72  4.88  0.41  2.03  5.28  6.91  13.82  4.06  28.85  14.22  32.10  2.03  40.23  17.47  22.76  10.97  55.68  42.26  4.88  10.57
                                    10.16  44.30  3.25  23.16  36.17  5.69  2.03  13.00  29.26  19.51  27.63  14.63  3.25  5.28  0.41  58.93  39.01  40.23  210.10  27.63  41.45  74.78  14.63
                                    17.88  28.85  104.85  4.47  27.63  4.47  34.14  1.22  38.20  21.13  53.64  12.19  7.72  6.10  19.51  19.91  4.47  6.50  43.48  7.32  6.91  3.25  0.41  13.82
                                    13.00  13.82  1.63  93.88  3.66  6.10  2.84  0.41  2.84  60.55  5.69  28.45  74.78  183.69  97.94  39.42  41.05  66.65  38.61  23.98  39.83  131.67  7.32
                                    17.88  1.22  0.41  21.54  13.00  10.57  3.66  5.28  8.13  38.61  131.67  10.97  59.74  11.79  1.63  14.63  89.41  39.83  10.97  3.25  105.25  3.66  2.03  36.58
                                    22.76  29.26  77.21  20.73  0.41  0.81  1.22  24.38  0.41  3.66  1.22  1.22  2.84  16.66  43.48  0.41  0.41  0.41  8.94  0.41  21.54  6.10  154.02  18.29
                                    36.98  41.05  0.41  0.81  1.63  0.81  215.39  0.81  0.41  0.41  2.03  1.22  0.41  0.81  10.97  14.63  4.88  1.22  3.25  0.81  41.86  3.25  2.44  8.53  26.42
                                    40.23  1.22  1.22  0.81  26.82  6.91  16.66  2.03  1.22  8.53  18.29  42.67  22.35  305.20  8.13  86.97  129.64  252.37  20.32  15.44  6.91  0.81  19.91  6.91  1.22
   ]

   ;unit transport costs ($USD / Km) - One (large) producer per location - 459 values
   set unit-transport-cost-vector1 [19.07  5.20  29.47  3.47  1.73  20.80  13.87  31.20  32.93  3.47  6.93  38.13  6.93  8.67  55.47  5.20  55.47  5.20  97.07  6.93  5.20  22.53  8.67  10.40  10.40  22.53
                                    3.47  1.73  2.30  1.73  2.30  1.73  1.73  1.73  5.20  48.53  6.93  2.30  1.73  57.20  5.20  95.33  15.60  13.87  17.33  39.87  2.30  2.30  8.67  1.73  3.47  1.73  13.87
                                    5.20  86.67  3.47  98.80  22.53  10.40  39.87  34.67  39.87  72.80  10.40  58.93  17.33  38.13  64.13  83.20  1.73  1.73  1.73  8.67  1.73  1.73  5.20  1.73  3.47  3.47
                                    1.73  5.20  27.73  46.80  8.67  53.73  1.73  22.53  12.13  3.47  17.33  27.73  2.30  2.30  1.73  2.30  1.73  1.73  2.30  2.30  1.73  1.73  2.30  2.30  2.30  1.73  19.07
                                    26.00  1.73  3.47  43.33  19.07  8.67  2.30  1.73  32.93  3.47  19.07  5.20  20.80  1.73  3.47  22.53  1.73  2.30  1.73  2.30  2.30  1.73  2.30  2.30  2.30  1.73  1.73
                                    36.40  1.73  5.20  6.93  60.67  2.30  1.73  1.73  27.73  1.73  3.47  5.20  29.47  6.93  3.47  1.73  1.73  3.47  2.30  48.53  3.47  13.87  15.60  8.67  20.80  5.20  6.93
                                    3.47  8.67  15.60  26.00  1.73  10.40  1.73  3.47  2.30  6.93  2.30  2.30  1.73  1.73  2.30  2.30  1.73  3.47  2.30  2.30  1.73  1.73  3.47  2.30  48.53  24.27  27.73
                                    6.93  12.13  15.60  29.47  55.47  5.20  5.20  3.47  8.67  45.07  53.73  12.13  5.20  1.73  1.73  1.73  3.47  6.93  6.93  12.13  1.73  88.40  1.73  34.67  20.80  1.73
                                    1.73  1.73  1.73  1.73  2.30  1.73  12.13  1.73  1.73  1.73  10.40  29.47  1.73  1.73  2.30  1.73  2.30  5.20  1.73  17.33  2.30  19.07  2.30  17.33  1.73  3.47  5.20
                                    5.20  1.73  3.47  24.27  1.73  1.73  10.40  3.47  3.47  1.73  1.73  8.67  15.60  1.73  2.30  1.73  41.60  3.47  131.73  1.73  10.40  3.47  38.13  20.80  10.40  1.73
                                    3.47  2.30  3.47  12.13  3.47  3.47  3.47  2.30  1.73  3.47  3.47  6.93  3.47  13.87  6.93  13.87  1.73  17.33  8.67  10.40  5.20  24.27  19.07  3.47  5.20  5.20  19.07
                                    1.73  10.40  15.60  3.47  1.73  6.93  13.87  8.67  12.13  6.93  1.73  3.47  2.30  26.00  17.33  17.33  90.13  12.13  19.07  32.93  6.93  8.67  13.87  45.07  3.47  12.13
                                    3.47  15.60  1.73  17.33  10.40  24.27  6.93  3.47  3.47  8.67  8.67  3.47  3.47  19.07  3.47  3.47  1.73  2.30  6.93  6.93  6.93  1.73  41.60  1.73  3.47  1.73  2.30
                                    1.73  26.00  3.47  13.87  32.93  79.73  43.33  17.33  19.07  29.47  17.33  10.40  17.33  57.20  3.47  8.67  1.73  2.30  10.40  6.93  5.20  1.73  3.47  5.20  17.33  57.20
                                    5.20  26.00  5.20  1.73  6.93  39.87  17.33  5.20  1.73  46.80  1.73  1.73  17.33  10.40  13.87  34.67  10.40  2.30  1.73  1.73  12.13  2.30  1.73  1.73  1.73  1.73  8.67
                                    19.07  2.30  2.30  2.30  5.20  2.30  10.40  3.47  67.60  8.67  17.33  19.07  2.30  1.73  1.73  1.73  93.60  1.73  2.30  2.30  1.73  1.73  2.30  1.73  5.20  6.93  3.47
                                    1.73  1.73  1.73  19.07  1.73  1.73  5.20  12.13  17.33  1.73  1.73  1.73  12.13  3.47  8.67  1.73  1.73  5.20  8.67  19.07  10.40  131.73  5.20  38.13  57.20  109.20
                                    10.40  6.93  3.47  1.73  8.67  3.47  1.73
   ]


   ;unit transport costs ($USD / Km) - Two (mid-sized) producers per location- 459 values
   set unit-transport-cost-vector2 [19.14  5.10  30.62  3.83  1.28  20.42  14.04  33.18  35.73  2.55  6.38  40.83  7.66  8.93  58.70  5.10  58.70  5.10  102.08  7.66  5.10  24.24  8.93  10.21  11.48  24.24
                                    2.55  1.28  1.15  2.55  1.15  1.28  1.28  1.28  5.10  49.76  7.66  1.15  1.28  61.25  5.10  100.80  16.59  14.04  19.14  42.11  1.15  1.15  7.66  2.55  2.55  2.55  14.04
                                    3.83  91.87  2.55  104.63  22.97  10.21  40.83  35.73  42.11  76.56  10.21  61.25  19.14  39.56  67.63  88.04  1.28  2.55  1.28  8.93  1.28  1.28  5.10  1.28  3.83  3.83
                                    1.28  5.10  29.35  48.49  8.93  57.42  1.28  24.24  12.76  2.55  19.14  29.35  1.15  1.15  1.28  1.15  1.28  1.28  1.15  1.15  1.28  1.28  1.15  1.15  1.15  1.28  20.42
                                    26.80  1.28  3.83  45.94  20.42  8.93  1.15  1.28  35.73  3.83  20.42  5.10  21.69  1.28  3.83  24.24  1.28  1.15  1.28  1.15  1.15  1.28  1.15  1.15  1.15  1.28  1.28
                                    38.28  1.28  5.10  7.66  63.80  1.15  1.28  1.28  29.35  1.28  2.55  5.10  31.90  7.66  2.55  1.28  1.28  2.55  1.15  51.04  3.83  14.04  16.59  8.93  21.69  5.10  6.38
                                    3.83  8.93  15.31  26.80  1.28  10.21  1.28  3.83  1.15  7.66  1.15  1.15  1.28  1.28  1.15  1.15  1.28  2.55  1.15  1.15  1.28  1.28  2.55  1.15  51.04  25.52  29.35
                                    6.38  11.48  16.59  30.62  58.70  3.83  5.10  3.83  8.93  47.21  57.42  12.76  5.10  1.28  1.28  2.55  2.55  6.38  6.38  12.76  1.28  93.15  1.28  37.00  22.97  2.55
                                    1.28  1.28  1.28  2.55  1.15  1.28  12.76  1.28  1.28  1.28  11.48  30.62  2.55  1.28  1.15  1.28  1.15  5.10  2.55  19.14  1.15  19.14  1.15  17.86  1.28  3.83  6.38
                                    6.38  1.28  3.83  25.52  1.28  1.28  11.48  3.83  3.83  1.28  1.28  8.93  15.31  1.28  1.15  1.28  44.66  3.83  140.36  1.28  11.48  2.55  40.83  21.69  10.21  1.28  2.55
                                    1.15  3.83  11.48  3.83  3.83  2.55  1.15  1.28  2.55  3.83  6.38  2.55  14.04  7.66  15.31  1.28  19.14  8.93  11.48  5.10  25.52  20.42  2.55  5.10  5.10  20.42  2.55
                                    11.48  16.59  3.83  1.28  6.38  14.04  8.93  12.76  7.66  2.55  2.55  1.15  26.80  17.86  19.14  95.70  12.76  19.14  34.45  7.66  8.93  14.04  48.49  2.55  12.76  2.55
                                    16.59  1.28  17.86  10.21  25.52  6.38  3.83  3.83  8.93  10.21  2.55  3.83  20.42  3.83  3.83  2.55  1.15  6.38  6.38  6.38  1.28  43.38  2.55  3.83  2.55  1.15  2.55
                                    28.07  3.83  14.04  34.45  84.22  44.66  19.14  19.14  30.62  17.86  11.48  19.14  59.97  3.83  8.93  1.28  1.15  10.21  6.38  5.10  2.55  2.55  3.83  17.86  59.97  5.10
                                    28.07  6.38  1.28  7.66  40.83  19.14  5.10  2.55  48.49  2.55  1.28  16.59  11.48  14.04  35.73  10.21  1.15  1.28  1.28  11.48  1.15  2.55  1.28  1.28  2.55  7.66  20.42
                                    1.15  1.15  1.15  5.10  1.15  10.21  3.83  70.18  8.93  17.86  19.14  1.15  1.28  1.28  1.28  98.25  1.28  1.15  1.15  1.28  1.28  1.15  1.28  5.10  7.66  2.55  1.28  2.55
                                    1.28  19.14  2.55  1.28  5.10  12.76  19.14  1.28  1.28  1.28  12.76  3.83  7.66  1.28  1.28  5.10  8.93  20.42  10.21  139.08  3.83  39.56  59.97  114.84  10.21  7.66
                                    3.83  1.28  10.21  3.83  1.28
   ]

   ;unit transport costs ($USD / Km) - Three (small) producers per location- 459 values
   set unit-transport-cost-vector3 [48.38  11.52  76.03  8.06  2.30  51.84  33.41  84.10  87.55  5.76  16.13  102.53  18.43  21.89  148.61  12.67  147.46  10.37  256.90  18.43  12.67  58.75  20.74  25.34  27.65
                                    59.90  6.91  3.46  1.15  3.46  1.15  1.15  3.46  3.46  12.67  126.72  17.28  1.15  2.30  154.37  11.52  255.74  42.62  33.41  47.23  105.98  1.15  1.15  19.58  4.61  6.91
                                    3.46  33.41  10.37  230.40  5.76  266.11  57.60  24.19  102.53  89.86  105.98  192.38  26.50  155.52  46.08  100.22  171.65  223.49  2.30  4.61  2.30  21.89  1.15  1.15
                                    12.67  3.46  8.06  9.22  2.30  12.67  73.73  123.26  23.04  144.00  2.30  61.06  32.26  6.91  46.08  74.88  1.15  1.15  1.15  1.15  1.15  3.46  1.15  1.15  1.15  2.30  1.15
                                    1.15  1.15  3.46  50.69  65.66  1.15  9.22  116.35  50.69  20.74  1.15  1.15  87.55  8.06  51.84  11.52  54.14  3.46  8.06  61.06  3.46  1.15  2.30  1.15  1.15  2.30  1.15
                                    1.15  1.15  1.15  1.15  96.77  3.46  12.67  17.28  162.43  1.15  3.46  2.30  72.58  3.46  5.76  12.67  79.49  18.43  5.76  3.46  1.15  5.76  1.15  130.18  9.22  35.71  40.32
                                    23.04  54.14  12.67  14.98  8.06  21.89  39.17  66.82  1.15  24.19  1.15  8.06  1.15  17.28  1.15  1.15  2.30  2.30  1.15  1.15  2.30  5.76  1.15  1.15  1.15  2.30  5.76  1.15
                                    127.87  63.36  72.58  16.13  29.95  41.47  78.34  147.46  10.37  11.52  8.06  21.89  118.66  145.15  31.10  11.52  1.15  1.15  4.61  5.76  16.13  16.13  33.41  3.46  233.86
                                    2.30  91.01  56.45  3.46  2.30  3.46  1.15  3.46  1.15  2.30  29.95  2.30  3.46  2.30  26.50  76.03  4.61  1.15  1.15  2.30  1.15  10.37  4.61  46.08  1.15  48.38  1.15  46.08
                                    3.46  9.22  13.82  13.82  2.30  8.06  63.36  3.46  3.46  27.65  8.06  8.06  2.30  3.46  23.04  38.02  2.30  1.15  2.30  110.59  9.22  354.82  3.46  27.65  5.76  102.53  52.99
                                    25.34  3.46  5.76  1.15  8.06  28.80  8.06  9.22  5.76  1.15  3.46  6.91  8.06  16.13  5.76  33.41  17.28  38.02  3.46  47.23  20.74  26.50  12.67  64.51  49.54  5.76  12.67
                                    12.67  51.84  4.61  27.65  42.62  6.91  3.46  16.13  34.56  23.04  32.26  17.28  4.61  6.91  1.15  67.97  46.08  47.23  243.07  32.26  48.38  86.40  17.28  20.74  33.41
                                    120.96  5.76  32.26  5.76  40.32  2.30  44.93  25.34  62.21  14.98  9.22  8.06  23.04  23.04  5.76  8.06  50.69  9.22  8.06  4.61  1.15  16.13  16.13  16.13  2.30  108.29
                                    4.61  8.06  3.46  1.15  3.46  70.27  6.91  33.41  86.40  211.97  112.90  46.08  48.38  77.18  44.93  27.65  46.08  152.06  9.22  20.74  2.30  1.15  25.34  16.13  12.67  4.61
                                    6.91  10.37  44.93  152.06  12.67  69.12  13.82  2.30  17.28  103.68  46.08  12.67  4.61  122.11  4.61  3.46  42.62  26.50  34.56  89.86  24.19  1.15  1.15  2.30  28.80  1.15
                                    4.61  2.30  2.30  3.46  19.58  50.69  1.15  1.15  1.15  10.37  1.15  25.34  8.06  178.56  21.89  42.62  48.38  1.15  1.15  2.30  1.15  248.83  1.15  1.15  1.15  3.46  2.30
                                    1.15  1.15  12.67  17.28  5.76  2.30  4.61  1.15  48.38  4.61  3.46  10.37  31.10  47.23  2.30  2.30  1.15  31.10  8.06  19.58  3.46  2.30  10.37  21.89  49.54  26.50  352.51
                                    10.37  100.22  149.76  291.46  24.19  18.43  8.06  1.15  23.04  8.06  2.30
   ]

   ;distances from intermediaries to wholesaler location (Bogota) calibrated according to real data (in Km.) - 94 values
   set distance-vector [77  106  93  74  0  73  102  75  83  67  103  109  113  115  83  90  52  69  47  60  51  47  42  26 60  22  32  47  69  25  87  76  145  123  133  171  114  63  78  77  46  60
                        92  91  24  28  29  35 48  68  45  79  75  78  40  37  104  98  118  49  34  42  62  65  68  72  28  43  69  80  45  51  30 71  62  25  15  23  33  27  43  75  149  132  112  108
                        90  92  115  101  97  112  122  75
   ]

   ;===========================================================================================================================
   ;
   ;                                   Scenarios for different transport cost values
   ;
   ;===========================================================================================================================
   ;
   ;reduction-factor indicates the reduction in transportation cost values for sensitivity analysis (0 < reduction-factor < 1)
   ;baseline line value is reduction-factor = 1
   ;
   ;---------------------------------------------------------------------------------------------------------------------------
   set inter-transport-cost inter-transport-cost * reduction-factor
   set unit-transport-cost-vector1 map [? * reduction-factor] unit-transport-cost-vector1
   set unit-transport-cost-vector2 map [? * reduction-factor] unit-transport-cost-vector2
   set unit-transport-cost-vector3 map [? * reduction-factor] unit-transport-cost-vector3
   ;---------------------------------------------------------------------------------------------------------------------------


   ;creation of producer agents
   let counter 0
   repeat 459 [;this process is generated as many times as the number of producer locations
               repeat number-producers-per-location
                     [create-producers 1 [setxy random-xcor random-ycor
                                          set last-profit 0
                                          set profits 0
                                          set color blue
                                          set size 1
                                          set producer-location counter
                                          ifelse (number-producers-per-location = 1)
                                                 [set unit-var-cost item counter unit-cost-vector1
                                                  set producer-quantity item counter production-quantity-vector1
                                                  set unit-transport-cost item counter unit-transport-cost-vector1
                                                 ];end first block ifelse (number-producers-per-location = 1)

                                                 [ifelse (number-producers-per-location = 2)
                                                   [set unit-var-cost item counter unit-cost-vector2
                                                    set producer-quantity item counter production-quantity-vector2
                                                    set unit-transport-cost item counter unit-transport-cost-vector2
                                                   ];end first block ifelse (number-producers-per-location = 2)

                                                   [;number-producers-per-location = 3
                                                    set unit-var-cost item counter unit-cost-vector3
                                                    set producer-quantity item counter production-quantity-vector3
                                                    set unit-transport-cost item counter unit-transport-cost-vector3
                                                   ];end second block ifelse (number-producers-per-location = 2)

                                                 ];end second block ifelse (number-producers-per-location = 1
                                           ];end create-producers
                     ]; end repeat number-producers-per-location
               set counter counter + 1
   ];end repeat 459

   ;create wholesalers
   create-wholesalers 1
       [setxy 0 11
        set color red
        set total-quantity 0
        set last-profit 0
        set size 2
        set profits 0 ;cumulative profits
       ]
   ;create farm markets
   create-farm-markets number-farm-markets ;urban marketplaces where producers sell directly
       [setxy 0 -11
        set color red
        set total-quantity 0
        set last-profit 0
        set size 2
        set profits 0; cumulative profits
       ]

   ;creation of intermediary agents
   set counter 0
   repeat 94 [;this process is generated as many times as the number of intermediary locations
              repeat number-intermediaries-per-location
                     [create-intermediaries 1 [
                                               set inter-location counter
                                               set distance-value item counter distance-vector
                                               let xpos0 item 0 [xcor] of wholesalers
                                               let ypos0 item 0 [ycor] of wholesalers
                                               let xpos1 item 0 [xcor] of farm-markets
                                               let ypos1 item 0 [ycor] of farm-markets
                                               set ycor random-float (ypos0 - ypos1) + ypos1 ;intermediaries are (visually) located between the two markets
                                               let value-a random-float ((max-pxcor - min-pxcor) * 0.75 - (max-pxcor - min-pxcor) * 0.25)
                                               let value-b (max-pxcor - min-pxcor) * 0.25 + min-pxcor
                                               set xcor value-a + value-b
                                               set profits 0  ;cumulative profits
                                               set last-profit 0 ;last round profits
                                               set size 1
                                               set color green
                     ];end create-intermediaries 1

              ];end repeat number-intermediaries-per-location
              set counter counter + 1
   ];end repeat 94

   ;assignment of intermediary locations to each producer (according to producer location and the table "inter-by-prod")
   ;assignment of distances to each intermediary location (according to producer location and the table "prod-inter-distance")
   ask producers [let row-value producer-location
                  set inter-location-list table:get inter-by-prod row-value
                  set distance-to-intermediary table:get prod-inter-distance row-value ;(distance in mts.)

                  ;assignment of clients (intermediaries + farm market) to producers
                  set q-value-list [] ;initialization
                  set producer-clients [] ;initialization

                  ;FIRST POSITION of producer-clients is the chosen farm market. Farm markets are all located in Bogota (intermediary location = 4)
                  set producer-clients lput (one-of [who] of farm-markets) producer-clients

                  ;remaining positions (memory - 1) are intermediaries (with location chosen according to inter-location-list)
                  repeat (memory - 1) [
                                        ;assignment of intermediaries
                                        let selected-location one-of inter-location-list
                                        let selected-intermediary one-of ([who] of intermediaries with [inter-location = selected-location])
                                        set producer-clients lput selected-intermediary producer-clients
                  ];end repeat (memory - 1)
                  ;there might be repeated values, so we delete them
                  set producer-clients remove-duplicates producer-clients
                  repeat (length producer-clients)  [set q-value-list lput q-producer-starting-value q-value-list]

   ];end ask producers

   ;producers create link with a client chosen randomly
   ask producers [ifelse (random-float 1) < active-probability [let chosen-client one-of producer-clients ;not all producers are active every iteration
                                                                create-link-with turtle chosen-client [set thickness 0.3
                                                                                                       set color black
                                                                                                      ]
                                                                set current-market chosen-client
                                                               ]
                                                               [
                                                                set current-market -1 ;producer is inactive
                                                               ]
   ];end ask producers

   reset-ticks

end

;-------------------------------------------------------
;                    PROCEDURES
;-------------------------------------------------------

to prod-int-farm-market-transactions
   ;producers sell all quantities to intermediaries / farm markets (and compute their profits)

   ;prices are computed according to end-consumer calibrated data: Aggregated monthly demand equation is Y($USD/Ton) = 336.51 - 0.0014*X(Ton.)
   ;to disaggregate it, we asume that intermediaries gets a markup "factor1" over the producer, and the wholesaler "factor2" over the intermediary
   ;producers sell to intermediaries at a price PPI($USD/Ton) = (336.51 - 0.0014*X(Ton.)) / (factor1 * factor2)
   ;intermediaries sell to wholesaler at PIW($COP/Kg) = (336.51 - 0.0014*X(Ton.)) / factor1
   ;this implies that, if Y = 281, factor1 = factor2 = 1.10, then PIW = 255, PPI = 232.

   ask intermediaries [
                       set my-producers [[who] of end1] of links with [end2 = (intermediary [who] of myself)] ;list of producers' id's that sell product to this intermediary
                       set buying-q 0 ;initialization
                       foreach my-producers [
                                             set buying-q buying-q + [producer-quantity] of producer ?

                       ];end foreach my-producers
                       ;price calculation
                       set buying-cost max list 0 ((336.51 - 0.0014 * buying-q) / (factor1 * factor2)) ;($USD / Ton)

                       ;profit calculation of producers (selling through intermediaries)
                       let location-of-intermediary inter-location
                       let price-to-producer buying-cost
                       let this-intermediary who
                       foreach my-producers [
                                             ask producer ? [let position-of-this-intermediary position location-of-intermediary inter-location-list
                                                             set last-profit (price-to-producer - unit-var-cost) * producer-quantity - item position-of-this-intermediary distance-to-intermediary * unit-transport-cost / 1000
                                                             set profits profits + last-profit

                                                             ;update of q values
                                                             let position-of-intermediary-in-producer-clients position this-intermediary producer-clients
                                                             let old-value item position-of-intermediary-in-producer-clients q-value-list
                                                             set q-value-list replace-item position-of-intermediary-in-producer-clients q-value-list (old-value * (1 - learning-rate) + learning-rate * last-profit)
                                             ];end ask producer ?
                       ];end foreach my-producers
   ];end ask intermediaries


   ask farm-markets [
                     set my-producers [[who] of end1] of links with [end2 = (farm-market [who] of myself)] ;list of producers' id's that sell product to this intermediary
                     set total-quantity 0; initialization
                     foreach my-producers [
                                           set total-quantity total-quantity + [producer-quantity] of producer ?
                     ];end foreach my-producers
                     ;price calculation
                     set market-buying-price max list 0 ((336.51 - 0.0014 * total-quantity) / (factor2))  ;($USD / Ton)

                     ;profit calculation of producers (selling through farm markets)
                     let location-of-farm-market 4 ;all farm markets are located in Bogota (location = 4, according to distance_matrix.csv)
                     let price-to-producer market-buying-price
                     let this-farm-market who
                     foreach my-producers [
                                           ask producer ? [let position-of-this-farm-market position location-of-farm-market inter-location-list
                                                           ;beware that the location of farm markets is the same as the intermedairy location = 4
                                                           set last-profit (price-to-producer - unit-var-cost) * producer-quantity - item position-of-this-farm-market distance-to-intermediary * unit-transport-cost / 1000
                                                           set profits profits + last-profit

                                                           ;update of q-values
                                                           let position-of-farm-market-in-producer-clients position this-farm-market producer-clients
                                                           let old-value item position-of-farm-market-in-producer-clients q-value-list ;this should be always the first position
                                                           set q-value-list replace-item position-of-farm-market-in-producer-clients q-value-list  (old-value * (1 - learning-rate) + learning-rate * last-profit)
                                           ];end ask producer ?
                     ];end foreach my-producers
   ];end ask farm-markets

end

to market-and-intermediary-transaction
   ;intermediaries, farm markets and wholesaler sell their quantities
   ask wholesalers [;all intemediaries sell their product to the wholesaler; that's why we do not visually represent any links between the intermediaries and the wholesaler
                    set total-quantity sum [buying-q] of intermediaries ;(Ton.)
                    set market-buying-price max list 0 ((336.51 - 0.0014 * total-quantity) / factor2) ;($USD / Ton)
                    set market-sale-price max list 0 (336.51 - 0.0014 * total-quantity)  ;($USD / Ton)
                    set last-profit (market-sale-price - market-buying-price) * total-quantity
                    set profits profits + last-profit

                    let payment market-buying-price ;payment intermediary receives ($USD / Ton.)
                    ask intermediaries [
                                        set last-profit (payment - buying-cost) * buying-q - distance-value * buying-q * inter-transport-cost
                                        set profits profits + last-profit


                    ];end ask intermediaries


   ];end ask wholesalers

   ask farm-markets [;farm market sell their quantities and compute profits
                     set market-sale-price max list 0 ((336.51 - 0.0014 * total-quantity * (count farm-markets))) ;($USD / Ton)
                     set last-profit (market-sale-price - market-buying-price) * total-quantity ;farm markets are located in Bogota, so that they do not incur in transportation costs
                     set profits profits + last-profit

   ];end ask farm-markets

end

to producers-update-selection
   ;updating of q-values
   ask producers [
        let this-producer-id who
        let this-producer-market current-market
        if current-market != -1 [ask link this-producer-id this-producer-market [die]]

        ;updating q-distribution
        let min-q-value min q-value-list
        let q-value-list-normalized map [? - min-q-value] q-value-list

        let q-value-sum sum q-value-list-normalized
        ifelse q-value-sum != 0 [;client is chosen according to q-value distribution
           let q-pdf map [? / q-value-sum] q-value-list-normalized ;density distribution

           let q-cdf (list item 0 q-pdf) ;initializing cumulative distribution as a list
           let rest but-first q-pdf

           foreach rest
              [let added ? + last q-cdf
               set q-cdf lput added q-cdf
              ]

           ifelse (random-float 1) < active-probability
                  [let randomval random-float 1 ;producer is active
                   let counter 0
                   let long length q-cdf

                   while [counter < long] ;another wat to put it: [counter <= (long - 1)]
                                         [let chosenval item counter q-cdf
                                          if randomval < chosenval [
                                                                    set current-market item counter producer-clients
                                                                    create-link-with turtle current-market [
                                                                                                            set thickness 0.3
                                                                                                            set color black
                                                                                                           ]
                                                                    set counter long
                                                                   ]
                                          set counter counter + 1
                   ];end while
                  ];end first block ifelse (random-float 1) < active-probability

                  [
                   set current-market -1 ;producer is inactive
                  ];end second block ifelse (random-float 1) < active-probability

       ];end first block ifelse q-value-sum
       [;client is chosen randomly
        ifelse (random-float 1) < active-probability [let chosen-client one-of producer-clients ;not all producers are active every iteration
                                       create-link-with turtle chosen-client [set thickness 0.3
                                                                              set color black
                                                                             ]
                                       set current-market chosen-client
                                      ];end first block ifelse (random-float 1) < active-probability
                                      [
                                       set current-market -1 ;producer is inactive
                                      ];end second block ifelse (random-float 1) < active-probability
       ];end second block ifelse q-value-sum
   ]

end

;-------------------------------------------------------
;                    MAIN PROGRAM
;-------------------------------------------------------
to go
   if ticks >= time-horizon [stop]
   prod-int-farm-market-transactions
   market-and-intermediary-transaction
   producers-update-selection ;producers update their selection on either one of the intermediaries or one of the the farm markets
   tick
end

;-------------------------------------------------------
;                    OUTPUT / REPORTERS
;-------------------------------------------------------

to-report traded-q-wholesaler
   report sum [total-quantity] of wholesalers
end

to-report traded-q-farm-market
  report sum [total-quantity] of farm-markets
end

to-report avg-lr-profit-prod
  report sum [last-profit] of producers with [current-market != -1] / count producers with [current-market != -1]
end

to-report max-lr-profit-prod
  report max [last-profit] of producers with [current-market != -1]
end

to-report min-lr-profit-prod
  report min [last-profit] of producers with [current-market != -1]
end

to-report avg-lr-profit-int
  report sum [last-profit] of intermediaries / count intermediaries
end

to-report max-lr-profit-int
  report max [last-profit] of intermediaries
end

to-report min-lr-profit-int
  report min [last-profit] of intermediaries
end

to-report price-wholesaler
  report sum [market-sale-price] of wholesalers / count wholesalers
end

to-report price-farm-markets
  report sum [market-sale-price] of farm-markets / count farm-markets
end

to-report producer-long-run-profit
  ifelse ticks >= 150 [
     report [last-profit] of producers
  ]
  [
     report 0
  ]
end

;Output of experiments 1-15 includes:
;traded-q-wholesaler
;traded-q-farm-market
;avg-lr-profit-prod
;max-lr-profit-prod
;min-lr-profit-prod
;avg-lr-profit-int
;max-lr-profit-int
;min-lr-profit-int
;price-wholesaler
;price-farm-markets

;Output of experiment 16 includes:
;producer-long-run-profit

@#$#@#$#@
GRAPHICS-WINDOW
751
19
1040
329
25
25
5.471
1
10
1
1
1
0
0
0
1
-25
25
-25
25
1
1
1
ticks
30.0

BUTTON
39
58
192
137
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
38
150
193
207
Go Once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
38
220
192
276
Go Forever
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
8
350
322
536
Producers' (most recent round) profit
NIL
NIL
-10000.0
10000.0
0.0
120.0
false
false
"" ""
PENS
"Frequency" 1.0 1 -13345367 true "set-plot-pen-mode 1 ;bar mode\nset-histogram-num-bars 50\nhistogram [last-profit] of producers with [current-market != -1]" "set-plot-pen-mode 1 ;bar mode\nset-histogram-num-bars 50\nhistogram [last-profit] of producers with [current-market != -1]"

PLOT
325
535
698
720
Intermediaries' avg. (most recent round) profit
NIL
NIL
0.0
100.0
5.0
10.0
true
true
"" ""
PENS
"avg value" 1.0 0 -16777216 true "plot sum [last-profit] of intermediaries / count intermediaries" "plot sum [last-profit] of intermediaries / count intermediaries"

PLOT
325
350
698
533
Market's traded quantities
NIL
NIL
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"Wholesale" 1.0 0 -2674135 true "" "plot sum [total-quantity] of wholesalers"
"Farm-markets" 1.0 0 -16777216 true "" "plot sum [total-quantity] of farm-markets"

PLOT
8
535
321
720
Avg sale price at different points
NIL
NIL
0.0
5.0
0.0
3.0
true
true
"" ""
PENS
"Wholesaler" 1.0 0 -2674135 true "" "plot sum [market-sale-price] of wholesalers / count wholesalers"
"Farm-market" 1.0 0 -16777216 true "" "plot sum [market-sale-price] of farm-markets / count farm-markets"
"Producer" 1.0 0 -13345367 true "" "plot sum [buying-cost] of intermediaries / count intermediaries"
"Intermediary" 1.0 0 -13840069 true "" "plot sum [market-buying-price] of wholesalers / count wholesalers"

SLIDER
230
50
460
83
number-producers-per-location
number-producers-per-location
1
3
3
1
1
NIL
HORIZONTAL

SLIDER
468
50
696
83
number-intermediaries-per-location
number-intermediaries-per-location
1
3
1
1
1
NIL
HORIZONTAL

MONITOR
230
92
459
137
Total number of producers
count producers
17
1
11

MONITOR
468
91
696
136
Total number of intermediaries
count intermediaries
17
1
11

SLIDER
233
184
695
217
number-farm-markets
number-farm-markets
1
50
25
1
1
NIL
HORIZONTAL

SLIDER
233
226
695
259
reduction-factor
reduction-factor
0.1
2
2
0.05
1
NIL
HORIZONTAL

PLOT
699
350
1067
533
Producers' (most recent transaction) profit
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"avg value" 1.0 0 -16777216 true "plot sum [last-profit] of producers with [current-market != -1] / count producers with [current-market != -1]" "plot sum [last-profit] of producers with [current-market != -1] / count producers with [current-market != -1]"
"max value" 1.0 0 -2674135 true "plot max [last-profit] of producers with [current-market != -1]" "plot max [last-profit] of producers with [current-market != -1]"
"min value" 1.0 0 -2674135 true "plot min [last-profit] of producers with [current-market != -1]" "plot min [last-profit] of producers with [current-market != -1]"

PLOT
700
535
1068
719
Intermediaries' (most recent round) profits
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"avg value" 1.0 0 -16777216 true "plot sum [last-profit] of intermediaries / count intermediaries" "plot sum [last-profit] of intermediaries / count intermediaries"
"max value" 1.0 0 -2674135 true "plot max [last-profit] of intermediaries" "plot max [last-profit] of intermediaries"
"min value" 1.0 0 -2674135 true "plot min [last-profit] of intermediaries" "plot min [last-profit] of intermediaries"

SLIDER
233
267
694
300
learning-rate
learning-rate
0
1
0.5
0.05
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment1_Prod1_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment2_Prod2_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment3_Prod3_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment4_Prod1_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment5_Prod2_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment6_Prod3_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment7_Prod1_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment8_Prod2_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment9_Prod3_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment10_Prod3_Inter3_FM1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment11_Prod3_Inter3_FM50" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment12_Prod3_Inter3_LR25" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment13_Prod3_Inter3_LR75" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment14_Prod3_Inter3_RF75" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment15_Prod3_Inter3_RF5" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment16_Prod3_Inter3_long-run_profit" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>producer-long-run-profit</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment17_Prod3_Inter1_long-run_profit" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>producer-long-run-profit</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment18_Prod1_Inter3_long-run_profit" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>producer-long-run-profit</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment19_Prod1_Inter1_long-run_profit" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>producer-long-run-profit</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment1_Prod1_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment2_Prod2_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment3_Prod3_Inter3" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment4_Prod1_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment5_Prod2_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment6_Prod3_Inter2" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment7_Prod1_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment8_Prod2_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RF2_Experiment9_Prod3_Inter1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>traded-q-wholesaler</metric>
    <metric>traded-q-farm-market</metric>
    <metric>avg-lr-profit-prod</metric>
    <metric>max-lr-profit-prod</metric>
    <metric>min-lr-profit-prod</metric>
    <metric>avg-lr-profit-int</metric>
    <metric>max-lr-profit-int</metric>
    <metric>min-lr-profit-int</metric>
    <metric>price-wholesaler</metric>
    <metric>price-farm-markets</metric>
    <enumeratedValueSet variable="number-producers-per-location">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reduction-factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-intermediaries-per-location">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-farm-markets">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
